@@ -55,35 +55,29 @@ def _get_page_titles(artist, title):
 
 def _get_lyrics(artist, title):
     
-    titles = _get_page_titles(artist, title)
-    
-    if titles:
-        page_title = titles[0]
-    else:
-        return
-    
-    args = {"action": "query",
-        "prop": "revisions",
-        "rvprop": "content",
-        "titles": page_title,
-        "format": "json",
-        }
-    
-    revisions = json.loads(_download(args))["query"]["pages"].popitem()[1]
-    
-    if not "revisions" in revisions:
-        return None
+    for page_title in _get_page_titles(artist, title):
+        args = {"action": "query",
+            "prop": "revisions",
+            "rvprop": "content",
+            "titles": page_title,
+            "format": "json",
+            }
         
-    content = revisions["revisions"][0]["*"]
-    
-    if content.startswith("#Redirect"):
-        n_title = content[content.find("[[") + 2:content.rfind("]]")]
-        return _get_lyrics(n_title)
-    
-    if "<lyrics>" in content:
-        return content[content.find("<lyrics>") + len("<lyrics>") : content.find("</lyrics>")].strip()
-    elif "<lyric>" in content:
-        return content[content.find("<lyric>") + len("<lyric>") : content.find("</lyric>")].strip()
+        revisions = json.loads(_download(args))["query"]["pages"].popitem()[1]
+        
+        if not "revisions" in revisions:
+            continue
+            
+        content = revisions["revisions"][0]["*"]
+        
+        if content.startswith("#Redirect"):
+            n_title = content[content.find("[[") + 2:content.rfind("]]")]
+            return _get_lyrics(n_title)
+        
+        if "<lyrics>" in content:
+            return content[content.find("<lyrics>") + len("<lyrics>") : content.find("</lyrics>")].strip()
+        elif "<lyric>" in content:
+            return content[content.find("<lyric>") + len("<lyric>") : content.find("</lyric>")].strip()
 
 def get_lyrics(artist, title, cache_dir=None):
     """
